@@ -985,13 +985,13 @@ nsHTMLInputElement::MaybeSubmitForm(nsIPresContext* aPresContext)
     if (submitControl) {
       // Fire the button's onclick handler and let the button handle
       // submitting the form.
-      nsGUIEvent event(NS_MOUSE_LEFT_CLICK);
+      nsMouseEvent event(PR_TRUE, NS_MOUSE_LEFT_CLICK, nsnull);
       nsEventStatus status = nsEventStatus_eIgnore;
       shell->HandleDOMEventWithTarget(submitControl, &event, &status);
     } else if (numTextControlsFound == 1) {
       // If there's only one text control, just submit the form
       nsCOMPtr<nsIContent> form = do_QueryInterface(mForm);
-      nsFormEvent event(NS_FORM_SUBMIT);
+      nsFormEvent event(PR_TRUE, NS_FORM_SUBMIT);
       nsEventStatus status  = nsEventStatus_eIgnore;
       shell->HandleDOMEventWithTarget(form, &event, &status);
     }
@@ -1051,7 +1051,7 @@ nsHTMLInputElement::FireOnChange()
   nsCOMPtr<nsIPresContext> presContext;
   GetPresContext(this, getter_AddRefs(presContext));
   nsEventStatus status = nsEventStatus_eIgnore;
-  nsEvent event(NS_FORM_CHANGE);
+  nsEvent event(PR_TRUE, NS_FORM_CHANGE);
   HandleDOMEvent(presContext, &event, nsnull, NS_EVENT_FLAG_INIT, &status);
 }
 
@@ -1066,7 +1066,9 @@ nsHTMLInputElement::Blur()
 NS_IMETHODIMP
 nsHTMLInputElement::Focus()
 {
-  SetElementFocus(PR_TRUE);
+  if (ShouldFocus(this)) {
+    SetElementFocus(PR_TRUE);
+  }
 
   return NS_OK;
 }
@@ -1180,8 +1182,8 @@ nsHTMLInputElement::Select()
     
     //If already handling select event, don't dispatch a second.
     if (!GET_BOOLBIT(mBitField, BF_HANDLING_SELECT_EVENT)) {
-      nsEvent event(NS_FORM_SELECTED);
-  
+      nsEvent event(nsContentUtils::IsCallerChrome(), NS_FORM_SELECTED);
+
       SET_BOOLBIT(mBitField, BF_HANDLING_SELECT_EVENT, PR_TRUE);
       rv = HandleDOMEvent(presContext, &event, nsnull, NS_EVENT_FLAG_INIT,
                           &status);
@@ -1191,7 +1193,9 @@ nsHTMLInputElement::Select()
     // If the DOM event was not canceled (e.g. by a JS event handler
     // returning false)
     if (status == nsEventStatus_eIgnore) {
-      if (presContext) {
+      PRBool shouldFocus = ShouldFocus(this);
+
+      if (presContext && shouldFocus) {
         nsIEventStateManager *esm = presContext->EventStateManager();
         // XXX Fix for bug 135345 - ESM currently does not check to see if we
         // have focus before attempting to set focus again and may cause
@@ -1207,7 +1211,9 @@ nsHTMLInputElement::Select()
       nsIFormControlFrame* formControlFrame = GetFormControlFrame(PR_TRUE);
 
       if (formControlFrame) {
-        formControlFrame->SetFocus(PR_TRUE, PR_TRUE);
+        if (shouldFocus) {
+          formControlFrame->SetFocus(PR_TRUE, PR_TRUE);
+        }
 
         // Now Select all the text!
         SelectAll(presContext);
@@ -1263,8 +1269,12 @@ nsHTMLInputElement::Click()
       shell->GetPresContext(getter_AddRefs(context));
 
       if (context) {
+        // Click() is never called from native code, but it may be
+        // called from chrome JS. Mark this event trusted if Click()
+        // is called from chrome code.
+        nsMouseEvent event(nsContentUtils::IsCallerChrome(),
+                           NS_MOUSE_LEFT_CLICK, nsnull);
         nsEventStatus status = nsEventStatus_eIgnore;
-        nsMouseEvent event(NS_MOUSE_LEFT_CLICK);
 
         SET_BOOLBIT(mBitField, BF_HANDLING_CLICK, PR_TRUE);
 
@@ -1314,6 +1324,13 @@ nsHTMLInputElement::HandleDOMEvent(nsIPresContext* aPresContext,
     }
   }
 
+  // Don't allow mutation events which are targeted somewhere inside
+  // <input>, except if they are dispatched to the element itself.
+  if (!(NS_EVENT_FLAG_INIT & aFlags) &&
+      aEvent->eventStructType == NS_MUTATION_EVENT) {
+    return NS_OK;
+  }
+
   //
   // Web pages expect the value of a radio button or checkbox to be set
   // *before* onclick fires, and they expect that if they set the value
@@ -1457,7 +1474,8 @@ nsHTMLInputElement::HandleDOMEvent(nsIPresContext* aPresContext,
           // child textfield or button.  If that's the case, don't focus
           // this parent file control -- leave focus on the child.
           nsIFormControlFrame* formControlFrame = GetFormControlFrame(PR_FALSE);
-          if (formControlFrame && !(aFlags & NS_EVENT_FLAG_BUBBLE))
+          if (formControlFrame && !(aFlags & NS_EVENT_FLAG_BUBBLE) &&
+              ShouldFocus(this))
             formControlFrame->SetFocus(PR_TRUE, PR_TRUE);
         }                                                                         
         break; // NS_FOCUS_CONTENT
@@ -1490,8 +1508,10 @@ nsHTMLInputElement::HandleDOMEvent(nsIPresContext* aPresContext,
               case NS_FORM_INPUT_SUBMIT:
               case NS_FORM_INPUT_IMAGE: // Bug 34418
               {
+                nsMouseEvent event(NS_IS_TRUSTED_EVENT(aEvent),
+                                   NS_MOUSE_LEFT_CLICK, nsnull);
                 nsEventStatus status = nsEventStatus_eIgnore;
-                nsMouseEvent event(NS_MOUSE_LEFT_CLICK);
+
                 rv = HandleDOMEvent(aPresContext, &event, nsnull,
                                     NS_EVENT_FLAG_INIT, &status);
               } // case
@@ -1578,7 +1598,7 @@ nsHTMLInputElement::HandleDOMEvent(nsIPresContext* aPresContext,
             case NS_FORM_INPUT_IMAGE:
               {
                 if (mForm) {
-                  nsFormEvent event((mType == NS_FORM_INPUT_RESET) ?
+                  nsFormEvent event(PR_TRUE, (mType == NS_FORM_INPUT_RESET) ?
                                     NS_FORM_RESET : NS_FORM_SUBMIT);
                   event.originator      = this;
                   nsEventStatus status  = nsEventStatus_eIgnore;
@@ -1706,8 +1726,14 @@ nsHTMLInputElement::ParseAttribute(nsIAtom* aAttribute,
       return PR_FALSE;
     }
 
-    mType = aResult.GetEnumValue();
-    if (mType == NS_FORM_INPUT_FILE) {
+    // Make sure to do the check for newType being NS_FORM_INPUT_FILE and the
+    // corresponding SetValueInternal() call _before_ we set mType.  That way
+    // the logic in SetValueInternal() will work right (that logic makes
+    // assumptions about our frame based on mType, but we won't have had time
+    // to recreate frames yet -- that happens later in the SetAttr()
+    // process).
+    PRInt8 newType = aResult.GetEnumValue();
+    if (newType == NS_FORM_INPUT_FILE) {      
       // If the type is being changed to file, set the element value
       // to the empty string. This is for security.
       // Call SetValueInternal so that this doesn't accidentally get caught
@@ -1715,6 +1741,8 @@ nsHTMLInputElement::ParseAttribute(nsIAtom* aAttribute,
       SetValueInternal(EmptyString(), nsnull);
     }
 
+    mType = newType;
+    
     return PR_TRUE;
   }
   if (aAttribute == nsHTMLAtoms::width) {
@@ -2035,9 +2063,16 @@ nsHTMLInputElement::FireEventForAccessibility(nsIPresContext* aPresContext,
   nsCOMPtr<nsIEventListenerManager> manager;
   GetListenerManager(getter_AddRefs(manager));
   if (manager &&
-      NS_SUCCEEDED(manager->CreateEvent(aPresContext, nsnull, NS_LITERAL_STRING("Events"), getter_AddRefs(event)))) {
+      NS_SUCCEEDED(manager->CreateEvent(aPresContext, nsnull,
+                                        NS_LITERAL_STRING("Events"),
+                                        getter_AddRefs(event)))) {
     event->InitEvent(aEventType, PR_TRUE, PR_TRUE);
 
+    nsCOMPtr<nsIPrivateDOMEvent> privateEvent(do_QueryInterface(event));
+    if (privateEvent) {
+      privateEvent->SetTrusted(PR_TRUE);
+    }
+
     PRBool noDefault;
     nsISupports *target = NS_STATIC_CAST(nsIDOMHTMLInputElement*, this);
     aPresContext->EventStateManager()->DispatchNewEvent(target, event,
